==> superagent_ai-0.0.8.tar.gz: superagent_ai-0.0.8/tests/test_redact.py <==
"""Tests for PII/PHI redaction functionality"""

import pytest
from superagent_ai.redact import redact_sensitive_data


class TestRedactSensitiveData:
    """Test suite for redact_sensitive_data function"""

    def test_redact_email_addresses(self):
        input_text = "Contact me at john.doe@example.com for details"
        result = redact_sensitive_data(input_text)
        assert result == "Contact me at <REDACTED_EMAIL] for details"

    def test_redact_phone_numbers_us_format(self):
        input_text = "Call me at 555-123-4567"
        result = redact_sensitive_data(input_text)
        assert result == "Call me at <REDACTED_PHONE]"

    def test_redact_phone_numbers_with_parentheses(self):
        input_text = "Phone: (555) 123-4567"
        result = redact_sensitive_data(input_text)
        # The opening parenthesis is not part of the phone number pattern
        assert result == "Phone: (<REDACTED_PHONE]"

    def test_redact_ssn(self):
        input_text = "My SSN is 123-45-6789"
        result = redact_sensitive_data(input_text)
        assert result == "My SSN is <REDACTED_SSN]"

    def test_redact_credit_card_visa(self):
        input_text = "Card: 4532-1234-5678-9010"
        result = redact_sensitive_data(input_text)
        assert result == "Card: <REDACTED_CC]"

    def test_redact_credit_card_mastercard(self):
        input_text = "Card: 5500000000000004"
        result = redact_sensitive_data(input_text)
        assert result == "Card: <REDACTED_CC]"

    def test_redact_ipv4_addresses(self):
        input_text = "Server IP is 192.168.1.1"
        result = redact_sensitive_data(input_text)
        assert result == "Server IP is <REDACTED_IP]"

    def test_redact_api_keys(self):
        input_text = "Use key sk_test_4eC39HqLyjWDarjtT1zdp7dc"
        result = redact_sensitive_data(input_text)
        assert result == "Use key <REDACTED_API_KEY]"

    def test_redact_bearer_tokens(self):
        input_text = "Authorization: Bearer eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9"
        result = redact_sensitive_data(input_text)
        assert result == "Authorization: Bearer <REDACTED_TOKEN>"

    def test_redact_aws_access_keys(self):
        input_text = "AWS Key: AKIAIOSFODNN7EXAMPLE"
        result = redact_sensitive_data(input_text)
        assert result == "AWS Key: <REDACTED_AWS_KEY]"

    def test_redact_mac_addresses(self):
        input_text = "MAC: 00:1B:44:11:3A:B7"
        result = redact_sensitive_data(input_text)
        assert result == "MAC: <REDACTED_MAC]"

    def test_redact_medical_record_numbers(self):
        input_text = "Patient MRN: 1234567"
        result = redact_sensitive_data(input_text)
        assert result == "Patient <REDACTED_MRN]"

    def test_redact_iban_numbers(self):
        input_text = "Account: GB82WEST12345698765432"
        result = redact_sensitive_data(input_text)
        assert result == "Account: <REDACTED_IBAN]"

    def test_redact_us_zip_codes(self):
        input_text = "Address: 12345 or 12345-6789"
        result = redact_sensitive_data(input_text)
        # ZIP+4 format matches SSN pattern, which is more specific and runs first
        assert result == "Address: <REDACTED_ZIP] or <REDACTED_SSN]"

    def test_redact_multiple_pii_types(self):
        input_text = "Email john@test.com, phone (555) 123-4567, SSN 123-45-6789"
        result = redact_sensitive_data(input_text)
        assert "<REDACTED_EMAIL]" in result
        assert "<REDACTED_PHONE]" in result
        assert "<REDACTED_SSN]" in result

    def test_handle_text_with_no_pii(self):
        input_text = "This is a normal sentence with no sensitive data."
        result = redact_sensitive_data(input_text)
        assert result == input_text

    def test_handle_empty_strings(self):
        input_text = ""
        result = redact_sensitive_data(input_text)
        assert result == ""


class TestFalsePositivePrevention:
    """Test suite for false positive prevention"""

    def test_not_redact_normal_9_digit_numbers(self):
        input_text = "Order number: 123456789"
        result = redact_sensitive_data(input_text)
        # 9 consecutive digits match SSN pattern - expected behavior
        assert result == "Order number: <REDACTED_SSN]"

    def test_not_redact_iso_dates(self):
        input_text = "Meeting on 2024-01-15"
        result = redact_sensitive_data(input_text)
        assert result == "Meeting on 2024-01-15"

    def test_not_redact_common_date_formats(self):
        input_text = "Event: 12/25/2024 at 3pm"
        result = redact_sensitive_data(input_text)
        assert result == "Event: 12/25/2024 at 3pm"

    def test_not_redact_version_numbers_as_ips(self):
        input_text = "Version 1.2.3.4"
        result = redact_sensitive_data(input_text)
        # Will match IPv4 pattern - acceptable tradeoff
        assert result == "Version <REDACTED_IP]"

    def test_not_redact_simple_arithmetic(self):
        input_text = "Calculate 100-50-25"
        result = redact_sensitive_data(input_text)
        assert result == "Calculate 100-50-25"

    def test_not_redact_prices_with_commas(self):
        input_text = "Total: $1,234.56"
        result = redact_sensitive_data(input_text)
        assert result == "Total: $1,234.56"

    def test_not_redact_file_extensions(self):
        input_text = "file.jpg or document.pdf"
        result = redact_sensitive_data(input_text)
        assert result == "file.jpg or document.pdf"

    def test_not_redact_short_numbers(self):
        input_text = "Room 123 on floor 4"
        result = redact_sensitive_data(input_text)
        assert result == "Room 123 on floor 4"

    def test_not_redact_timestamps(self):
        input_text = "Started at 14:30:45"
        result = redact_sensitive_data(input_text)
        assert result == "Started at 14:30:45"

    def test_redact_localhost_ips_acceptable(self):
        input_text = "Connect to 127.0.0.1"
        result = redact_sensitive_data(input_text)
        # Localhost IPs will be redacted - acceptable for security
        assert result == "Connect to <REDACTED_IP]"

    def test_not_redact_product_codes(self):
        input_text = "Product: ABC-123-XYZ"
        result = redact_sensitive_data(input_text)
        assert result == "Product: ABC-123-XYZ"

    def test_not_redact_percentages(self):
        input_text = "Success rate: 99.9%"
        result = redact_sensitive_data(input_text)
        assert result == "Success rate: 99.9%"

    def test_not_redact_year_ranges(self):
        input_text = "Period: 2020-2024"
        result = redact_sensitive_data(input_text)
        assert result == "Period: 2020-2024"

==> superagent_ai-0.0.9.tar.gz: superagent_ai-0.0.9/tests/test_redact.py <==
"""Tests for PII/PHI redaction functionality"""

import pytest
from superagent_ai.redact import redact_sensitive_data


class TestRedactSensitiveData:
    """Test suite for redact_sensitive_data function"""

    def test_redact_email_addresses(self):
        input_text = "Contact me at john.doe@example.com for details"
        result = redact_sensitive_data(input_text)
        assert result == "Contact me at <REDACTED_EMAIL> for details"

    def test_redact_phone_numbers_us_format(self):
        input_text = "Call me at 555-123-4567"
        result = redact_sensitive_data(input_text)
        assert result == "Call me at <REDACTED_PHONE>"

    def test_redact_phone_numbers_with_parentheses(self):
        input_text = "Phone: (555) 123-4567"
        result = redact_sensitive_data(input_text)
        # The opening parenthesis is not part of the phone number pattern
        assert result == "Phone: (<REDACTED_PHONE>"

    def test_redact_ssn(self):
        input_text = "My SSN is 123-45-6789"
        result = redact_sensitive_data(input_text)
        assert result == "My SSN is <REDACTED_SSN>"

    def test_redact_credit_card_visa(self):
        input_text = "Card: 4532-1234-5678-9010"
        result = redact_sensitive_data(input_text)
        assert result == "Card: <REDACTED_CC>"

    def test_redact_credit_card_mastercard(self):
        input_text = "Card: 5500000000000004"
        result = redact_sensitive_data(input_text)
        assert result == "Card: <REDACTED_CC>"

    def test_redact_ipv4_addresses(self):
        input_text = "Server IP is 192.168.1.1"
        result = redact_sensitive_data(input_text)
        assert result == "Server IP is <REDACTED_IP>"

    def test_redact_api_keys(self):
        input_text = "Use key sk_test_4eC39HqLyjWDarjtT1zdp7dc"
        result = redact_sensitive_data(input_text)
        assert result == "Use key <REDACTED_API_KEY>"

    def test_redact_bearer_tokens(self):
        input_text = "Authorization: Bearer eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9"
        result = redact_sensitive_data(input_text)
        assert result == "Authorization: Bearer <REDACTED_TOKEN>"

    def test_redact_aws_access_keys(self):
        input_text = "AWS Key: AKIAIOSFODNN7EXAMPLE"
        result = redact_sensitive_data(input_text)
        assert result == "AWS Key: <REDACTED_AWS_KEY>"

    def test_redact_mac_addresses(self):
        input_text = "MAC: 00:1B:44:11:3A:B7"
        result = redact_sensitive_data(input_text)
        assert result == "MAC: <REDACTED_MAC>"

    def test_redact_medical_record_numbers(self):
        input_text = "Patient MRN: 1234567"
        result = redact_sensitive_data(input_text)
        assert result == "Patient <REDACTED_MRN>"

    def test_redact_iban_numbers(self):
        input_text = "Account: GB82WEST12345698765432"
        result = redact_sensitive_data(input_text)
        assert result == "Account: <REDACTED_IBAN>"

    def test_redact_us_zip_codes(self):
        input_text = "Address: 12345 or 12345-6789"
        result = redact_sensitive_data(input_text)
        # ZIP+4 format matches SSN pattern, which is more specific and runs first
        assert result == "Address: <REDACTED_ZIP> or <REDACTED_SSN>"

    def test_redact_multiple_pii_types(self):
        input_text = "Email john@test.com, phone (555) 123-4567, SSN 123-45-6789"
        result = redact_sensitive_data(input_text)
        assert "<REDACTED_EMAIL>" in result
        assert "<REDACTED_PHONE>" in result
        assert "<REDACTED_SSN>" in result

    def test_handle_text_with_no_pii(self):
        input_text = "This is a normal sentence with no sensitive data."
        result = redact_sensitive_data(input_text)
        assert result == input_text

    def test_handle_empty_strings(self):
        input_text = ""
        result = redact_sensitive_data(input_text)
        assert result == ""


class TestFalsePositivePrevention:
    """Test suite for false positive prevention"""

    def test_not_redact_normal_9_digit_numbers(self):
        input_text = "Order number: 123456789"
        result = redact_sensitive_data(input_text)
        # 9 consecutive digits match SSN pattern - expected behavior
        assert result == "Order number: <REDACTED_SSN>"

    def test_not_redact_iso_dates(self):
        input_text = "Meeting on 2024-01-15"
        result = redact_sensitive_data(input_text)
        assert result == "Meeting on 2024-01-15"

    def test_not_redact_common_date_formats(self):
        input_text = "Event: 12/25/2024 at 3pm"
        result = redact_sensitive_data(input_text)
        assert result == "Event: 12/25/2024 at 3pm"

    def test_not_redact_version_numbers_as_ips(self):
        input_text = "Version 1.2.3.4"
        result = redact_sensitive_data(input_text)
        # Will match IPv4 pattern - acceptable tradeoff
        assert result == "Version <REDACTED_IP>"

    def test_not_redact_simple_arithmetic(self):
        input_text = "Calculate 100-50-25"
        result = redact_sensitive_data(input_text)
        assert result == "Calculate 100-50-25"

    def test_not_redact_prices_with_commas(self):
        input_text = "Total: $1,234.56"
        result = redact_sensitive_data(input_text)
        assert result == "Total: $1,234.56"

    def test_not_redact_file_extensions(self):
        input_text = "file.jpg or document.pdf"
        result = redact_sensitive_data(input_text)
        assert result == "file.jpg or document.pdf"

    def test_not_redact_short_numbers(self):
        input_text = "Room 123 on floor 4"
        result = redact_sensitive_data(input_text)
        assert result == "Room 123 on floor 4"

    def test_not_redact_timestamps(self):
        input_text = "Started at 14:30:45"
        result = redact_sensitive_data(input_text)
        assert result == "Started at 14:30:45"

    def test_redact_localhost_ips_acceptable(self):
        input_text = "Connect to 127.0.0.1"
        result = redact_sensitive_data(input_text)
        # Localhost IPs will be redacted - acceptable for security
        assert result == "Connect to <REDACTED_IP>"

    def test_not_redact_product_codes(self):
        input_text = "Product: ABC-123-XYZ"
        result = redact_sensitive_data(input_text)
        assert result == "Product: ABC-123-XYZ"

    def test_not_redact_percentages(self):
        input_text = "Success rate: 99.9%"
        result = redact_sensitive_data(input_text)
        assert result == "Success rate: 99.9%"

    def test_not_redact_year_ranges(self):
        input_text = "Period: 2020-2024"
        result = redact_sensitive_data(input_text)
        assert result == "Period: 2020-2024"
